============
waf-libs
============

various terrible helper functions for stuff


NOTE: this library only supports python 3 and above

usage
-------------
see `USAGE.rst <https://bitbucket.org/waf/waf-libs/src/main/USAGE.rst>`_
